package sun.management.snmp.jvminstr;

import java.lang.management.ManagementFactory;
import java.util.List;
import sun.management.snmp.util.SnmpNamedListTableCache;
import java.lang.management.MemoryPoolMXBean;
import com.sun.jmx.mbeanserver.Util;
import sun.management.snmp.util.JvmContextFactory;
import java.util.Map;
import sun.management.snmp.util.SnmpTableHandler;
import com.sun.jmx.snmp.SnmpStatusException;
import com.sun.jmx.snmp.SnmpOid;
import com.sun.jmx.snmp.agent.SnmpStandardObjectServer;
import com.sun.jmx.snmp.agent.SnmpMib;
import sun.management.snmp.util.MibLogger;
import sun.management.snmp.util.SnmpTableCache;
import sun.management.snmp.jvmmib.JvmMemPoolTableMeta;

public class JvmMemPoolTableMetaImpl extends JvmMemPoolTableMeta
{
    static final long serialVersionUID = -2525820976094284957L;
    protected SnmpTableCache cache;
    static final MibLogger log;
    
    public JvmMemPoolTableMetaImpl(SnmpMib snmpMib, SnmpStandardObjectServer snmpStandardObjectServer) {
        super(snmpMib, snmpStandardObjectServer);
        this.cache = new JvmMemPoolTableMetaImpl.JvmMemPoolTableCache(((JVM_MANAGEMENT_MIB_IMPL)snmpMib).validity() * 30L);
    }
    
    protected SnmpOid getNextOid(Object o) throws SnmpStatusException {
        return this.getNextOid(null, o);
    }
    
    protected SnmpOid getNextOid(SnmpOid obj, Object o) throws SnmpStatusException {
        int debugOn = JvmMemPoolTableMetaImpl.log.isDebugOn();
        try {
            if (!(debugOn == 0)) {
                JvmMemPoolTableMetaImpl.log.debug("getNextOid", "previous=" + obj);
            }
            SnmpTableHandler handler = this.getHandler(o);
            if (handler == null) {
                if (!(debugOn == 0)) {
                    JvmMemPoolTableMetaImpl.log.debug("getNextOid", "handler is null!");
                }
                throw new SnmpStatusException(224);
            }
            else {
                SnmpOid next = handler.getNext(obj);
                if (!(debugOn == 0)) {
                    JvmMemPoolTableMetaImpl.log.debug("getNextOid", "next=" + next);
                }
                if (next == null) {
                    throw new SnmpStatusException(224);
                }
                return next;
            }
        }
        catch (SnmpStatusException obj2) {
            if (!(debugOn == 0)) {
                JvmMemPoolTableMetaImpl.log.debug("getNextOid", "End of MIB View: " + obj2);
            }
            throw obj2;
        }
        catch (RuntimeException obj3) {
            if (!(debugOn == 0)) {
                JvmMemPoolTableMetaImpl.log.debug("getNextOid", "Unexpected exception: " + obj3);
            }
            if (!(debugOn == 0)) {
                JvmMemPoolTableMetaImpl.log.debug("getNextOid", obj3);
            }
            throw obj3;
        }
    }
    
    protected boolean contains(SnmpOid snmpOid, Object o) {
        SnmpTableHandler handler = this.getHandler(o);
        return handler != null && handler.contains(snmpOid);
    }
    
    public Object getEntry(SnmpOid snmpOid) throws SnmpStatusException {
        if (snmpOid == null) {
            throw new SnmpStatusException(224);
        }
        Map<String, JvmMemPoolEntryImpl> map = (Map)Util.cast(JvmContextFactory.getUserData());
        long oidArc = snmpOid.getOidArc(0);
        String s = (map == null) ? null : ("JvmMemPoolTable.entry." + oidArc);
        if (map != null) {
            Object value = map.get(s);
            if (value != null) {
                return value;
            }
        }
        SnmpTableHandler handler = this.getHandler(map);
        if (handler == null) {
            throw new SnmpStatusException(224);
        }
        Object data = handler.getData(snmpOid);
        if (data == null) {
            throw new SnmpStatusException(224);
        }
        if (JvmMemPoolTableMetaImpl.log.isDebugOn()) {
            JvmMemPoolTableMetaImpl.log.debug("getEntry", "data is a: " + data.getClass().getName());
        }
        JvmMemPoolEntryImpl jvmMemPoolEntryImpl = new JvmMemPoolEntryImpl((MemoryPoolMXBean)data, (int)oidArc);
        if (map != null && jvmMemPoolEntryImpl != null) {
            map.put(s, jvmMemPoolEntryImpl);
            return jvmMemPoolEntryImpl;
        }
        return jvmMemPoolEntryImpl;
    }
    
    protected SnmpTableHandler getHandler(Object x) {
        Map<String, SnmpTableHandler> map;
        if ((x instanceof Map)) {
            map = (Map)Util.cast(x);
        }
        else {
            map = null;
        }
        if (map != null) {
            SnmpTableHandler snmpTableHandler = (SnmpTableHandler)map.get("JvmMemPoolTable.handler");
            if (snmpTableHandler != null) {
                return snmpTableHandler;
            }
        }
        SnmpTableHandler tableHandler = this.cache.getTableHandler();
        if (map != null && tableHandler != null) {
            map.put("JvmMemPoolTable.handler", tableHandler);
            return tableHandler;
        }
        return tableHandler;
    }
    
    static {
        log = new MibLogger(JvmMemPoolTableMetaImpl.class);
    }
    
    private static class JvmMemPoolTableCache extends SnmpNamedListTableCache
    {
        static final long serialVersionUID = -1755520683086760574L;
        
        JvmMemPoolTableCache(long validity) {
            this.validity = validity;
        }
        
        protected String getKey(Object o, List<?> list, int n, Object o2) {
            if (o2 == null) {
                return null;
            }
            String name = ((MemoryPoolMXBean)o2).getName();
            JvmMemPoolTableMetaImpl.log.debug("getKey", "key=" + name);
            return name;
        }
        
        public SnmpTableHandler getTableHandler() {
            return this.getTableDatas(JvmContextFactory.getUserData());
        }
        
        protected String getRawDatasKey() {
            return "JvmMemManagerTable.getMemoryPools";
        }
        
        protected List<MemoryPoolMXBean> loadRawDatas(Map<Object, Object> map) {
            return ManagementFactory.getMemoryPoolMXBeans();
        }
    }
}
